<?php declare(strict_types=1);
/**
 * Abstract class for widgets that will fetch articles from Open Content.
 * Adds additional functionality to handle form-data.
 */

namespace Infomaker\Everyware\Base;

use Infomaker\Everyware\Support\Str;
use OcAPI;

/**
 * OCWidget
 *
 * @deprecated This class has been removed from use. Use classes in Everyware\ProjectPlugin\Components to write widget components. Will be removed in 1.0.0
 *
 * @link    http://infomaker.se
 * @package Infomaker\Everyware\Base
 * @since   Infomaker\Everyware\Base\OCWidget 0.1
 */
abstract class OcWidget extends Widget
{

    /**
     * Contains the API-instance to connect to Open Content
     *
     * @var OcAPI
     */
    protected $oc_api;

    /**
     * Default values for making text search requests against the OCAPI class
     *
     * @since 1.0
     * @var array
     */
    private $oc_fields = [
        'oc_query' => '',
        'oc_query_start' => 0,
        'oc_query_limit' => 10,
        'oc_query_sort' => '',
        'pubdate_start' => '',
        'pubdate_stop' => '',
        'include_future_articles' => false,
        'facet' => null,
        'facet_limit' => null,
        'facet_mincount' => null,
        'use_cache' => true,
        'create_article' => true,
        'use_raw' => false
    ];

    /**
     * OCWidget constructor.
     *
     * @since 0.1
     *
     * @param string $id
     * @param array  $widget_options
     * @param array  $control_options
     */
    public function __construct($id, $widget_options = [], $control_options = [])
    {
        $this->oc_api = new OcAPI();
        parent::__construct($id, $widget_options, $control_options);
    }

    /**
     * Function to get available sort options
     *
     * @return array|mixed
     */
    protected function sortingsSelectData()
    {
        $sort_options = $this->oc_api->get_oc_sort_options();

        if (isset($sort_options->sortings)) {
            return array_map(function ($option) {
                return [
                    'value' => $option->name,
                    'text' => $option->name
                ];
            }, $sort_options->sortings);
        }

        return [];
    }

    /**
     * Function to get available properties from a contenttype as select-data
     *
     * @param string $contenttype
     *
     * @since 0.1
     * @return array
     */
    protected function propertiesSelectData($contenttype = 'Article'): array
    {
        $query_options = $this->oc_api->get_content_types();

        $properties = [];
        foreach ($query_options[$contenttype] as $property) {
            $property = $property[0] ?? '';
            if ( ! Str::isEmpty($property)) {
                $properties[] = [
                    'value' => $property,
                    'text' => Str::ucfirst($property)
                ];
            }
        }

        return $properties;
    }

    /**
     * Function to get available contenttypes options
     *
     * @since 0.1
     * @return array
     */
    protected function contenttypesSelectData(): array
    {
        return array_map(function ($contenttype) {
            return [
                'value' => $contenttype,
                'text' => $contenttype
            ];
        }, array_keys($this->oc_api->get_content_types()));
    }
}
